{# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2014, 2015, 2016, 2017 CERN.
#
# Invenio is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}

{%- extends config.OAUTHCLIENT_SETTINGS_TEMPLATE %}

{% from "invenio_oauthclient/_macros.html" import render_field, form_errors %}

{% block page_body %}
<div class="row">
  {%- block signup_panel %}
  <div class="col-md-6 well well-lg col-md-offset-3">
    {%- block signup_header %}
      {%- block signup_app_icon %}
        {% if app_icon -%}
          <span class="pull-right"><i class="{{app_icon}} fa-5x"></i></span>
        {%- endif %}
      {%- endblock %}
      <h3> {{ _('Sign-up with %(title)s!', title=app_title) }}</h3>
      <p>{{ _('Fill in your details to complete your registration. You only have to do this once.') }}</p>
      <hr />
    {% endblock %}
    {%- block signup_form %}
    <form name="edit" method="post" role="form">
      {%- for field in form %}
        {{ render_field(field) }}
      {%- endfor %}
    </form>
    {%- endblock %}
  </div>
  {%- endblock %}
</div>
{% endblock %}
